@@ -36,14 +36,26 @@ ParamDef = TypedDict('ParamDef', {
     "default": Optional[Any],
 })
 ParamDefs = Dict[str, ParamDef]
+Backends = TypedDict('Backends', {
+    "executor_mng": str,
+    "jobs": str,
+    "logger": List[str],
+    "mtype": str,
+    "progress": str,
+    "queue_mng": Dict[str, str],
+    "status_emitter": List[str],
+    "task_mng": Dict[str, str],
+})
 MaintenanceResponse = TypedDict('MaintenanceResponse', {
     "is_maintenance": bool,
 })
 VersionResponse = TypedDict('VersionResponse', {
-    "xyme_version": str,
-    "time": str,
-    "caller_api_version": int,
     "api_version": int,
+    "backends": Optional[Backends],
+    "caller_api_version": int,
+    "time": str,
+    "xyme_version_full": str,
+    "xyme_version": str,
 })
 ReadNode = TypedDict('ReadNode', {
     "redis_key": str,
@@ -243,3 +255,12 @@ DynamicStatusResponse = TypedDict('DynamicStatusResponse', {
 DynamicResults = TypedDict('DynamicResults', {
     "results": List[Any],
 })
+CacheStats = TypedDict('CacheStats', {
+    "approx_total": int,
+    "effectiveness": float,
+    "hits": int,
+    "miss": int,
+})
+QueueMode = TypedDict('QueueMode', {
+    "mode": str,
+})
